.gadjo-multi-select-widget--field {
  margin-bottom: 0.2em; }

.gadjo-multi-select-widget--select-button-container {
  display: flex;
  gap: 0.5em; }

.gadjo-multi-select-widget--field select {
  min-width: 0; }

.gadjo-multi-select-widget--field button {
  margin-top: auto;
  margin-bottom: auto; }

.gadjo-multi-select-widget--field:first-of-type .gadjo-multi-select-widget--button-remove {
  display: none; }

.gadjo-multi-select-widget--button-add::before {
  content: "\f067";
  /* plus */
  font-family: FontAwesome; }

.gadjo-multi-select-widget--button-remove::before {
  content: "\f068";
  /* minus */
  font-family: FontAwesome; }

/*# sourceMappingURL=gadjo.multiselectwidget.css.map */