{% load gadjo static %}

{% if cnil_compliant_visits_tracking_js_backoffice %}
  <script type="text/javascript" data-template="portal-agent">
    if (navigator.doNotTrack != '1') {
      {{ cnil_compliant_visits_tracking_js_backoffice|safe }}
    }
  </script>
{% elif visits_tracking_js_backoffice %}
  <script type="text/javascript" src="{{ site_base }}{% static 'js/cookie_usage_consent.js' %}?{% start_timestamp %}"></script>
  <script type="text/javascript" data-template="portal-agent">
    if (has_consent()) {
      {{ visits_tracking_js_backoffice|safe }}
    }
  </script>
{% endif %}
